;; Generated package description from rfc-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "rfc-mode" "1.4.2.0.20260617.2" "RFC document browser and viewer" '((emacs "25.1")) :commit "0ab3e0b5eca45e7baaea748063b8590d08b55789" :authors '(("Nicolas Martyanoff" . "nicolas@n16f.net")) :maintainer '("Nicolas Martyanoff" . "nicolas@n16f.net") :url "https://github.com/galdor/rfc-mode")
